@@ -1,6 +1,6 @@
 package MaxMind::DB::Reader::PP;
 {
-  $MaxMind::DB::Reader::PP::VERSION = '0.050001';
+  $MaxMind::DB::Reader::PP::VERSION = '0.050002';
 }
 BEGIN {
   $MaxMind::DB::Reader::PP::AUTHORITY = 'cpan:TJMATHER';
@@ -10,6 +10,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
+use Carp qw( confess );
 use MaxMind::DB::Types qw( Str Int );
 
 use Moo;
@@ -41,12 +42,15 @@ sub BUILD {
 
     my $file = $self->file();
 
-    die "The file you specified ($file) does not exist"
+    die qq{Error opening database file "$file": The file does not exist.}
         unless -e $file;
 
-    die "The file you specified ($file) cannot be read"
+    die qq{Error opening database file "$file": The file cannot be read.}
         unless -r _;
 
+    # Build the metadata right away to ensure file's validity
+    $self->metadata;
+
     return;
 }
 
@@ -130,6 +134,9 @@ sub _get_entry_data {
     my $resolved
         = ( $offset - $self->node_count() ) + $self->_search_tree_size();
 
+            confess q{The MaxMind DB file's search tree is corrupt}
+    if $resolved > $self->_data_source_size;
+
     if (DEBUG) {
         my $node_count = $self->node_count();
         my $tree_size  = $self->_search_tree_size();
@@ -176,7 +183,7 @@ MaxMind::DB::Reader::PP - Pure Perl implementation of the MaxMind DB reader code
 
 =head1 VERSION
 
-version 0.050001
+version 0.050002
 
 =head1 AUTHORS
 
